summaryrefslogtreecommitdiffstats
path: root/kdevdesigner/designer/listboxrename.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'kdevdesigner/designer/listboxrename.cpp')
-rw-r--r--kdevdesigner/designer/listboxrename.cpp26
1 files changed, 13 insertions, 13 deletions
diff --git a/kdevdesigner/designer/listboxrename.cpp b/kdevdesigner/designer/listboxrename.cpp
index d51381dd..53f0deea 100644
--- a/kdevdesigner/designer/listboxrename.cpp
+++ b/kdevdesigner/designer/listboxrename.cpp
@@ -1,15 +1,15 @@
/**********************************************************************
** Copyright (C) 2002 Trolltech AS. All rights reserved.
**
** This file is part of Qt Designer.
**
** This file may be distributed and/or modified under the terms of the
** GNU General Public License version 2 as published by the Free Software
** Foundation and appearing in the file LICENSE.GPL included in the
** packaging of this file.
**
-** Licensees holding valid Qt Enterprise Edition or Qt Professional Edition
-** licenses may use this file in accordance with the Qt Commercial License
+** Licensees holding valid TQt Enterprise Edition or TQt Professional Edition
+** licenses may use this file in accordance with the TQt Commercial License
** Agreement provided with the Software.
**
** This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
@@ -17,7 +17,7 @@
**
** See http://www.trolltech.com/gpl/ for GPL licensing information.
** See http://www.trolltech.com/pricing.html or email sales@trolltech.com for
-** information about Qt Commercial License Agreements.
+** information about TQt Commercial License Agreements.
**
** Contact info@trolltech.com if any conditions of this licensing are
** not clear to you.
@@ -29,7 +29,7 @@
#include <tqtimer.h>
#include "listboxrename.h"
-class EditableListBoxItem : public QListBoxItem
+class EditableListBoxItem : public TQListBoxItem
{
public:
void setText( const TQString & text )
@@ -84,24 +84,24 @@ bool ListBoxRename::eventFilter( TQObject *, TQEvent * event )
switch ( ((TQKeyEvent *) event)->key() ) {
- case Qt::Key_F2:
+ case TQt::Key_F2:
activity = FALSE;
clickedItem = src->item( src->currentItem() );
showLineEdit();
break;
- case Qt::Key_Escape:
+ case TQt::Key_Escape:
if ( !ed->isHidden() ) {
hideLineEdit(); // abort rename
return TRUE;
}
break;
- case Qt::Key_Up:
- case Qt::Key_Down:
- case Qt::Key_PageUp:
- case Qt::Key_PageDown:
+ case TQt::Key_Up:
+ case TQt::Key_Down:
+ case TQt::Key_PageUp:
+ case TQt::Key_PageDown:
if ( !ed->isHidden() )
return TRUE; // Filter out the keystrokes
@@ -113,7 +113,7 @@ bool ListBoxRename::eventFilter( TQObject *, TQEvent * event )
case TQEvent::Resize:
if ( clickedItem && ed && !ed->isHidden() ) {
- TQRect rect = src->itemRect( clickedItem );
+ TQRect rect = src->tqitemRect( clickedItem );
ed->resize( rect.right() - rect.left() - 1,
rect.bottom() - rect.top() - 1 );
}
@@ -130,7 +130,7 @@ void ListBoxRename::showLineEdit()
{
if ( !clickedItem || activity )
return;
- TQRect rect = src->itemRect( clickedItem );
+ TQRect rect = src->tqitemRect( clickedItem );
ed->resize( rect.right() - rect.left() - 1,
rect.bottom() - rect.top() - 1 );
ed->move( rect.left() + 1, rect.top() + 1 );
@@ -1,15 +1,15 @@
** Copyright (C) 2002 Trolltech AS. All rights reserved.
**
-** This file is part of Qt Designer.
+** This file is part of TQt Designer.
**
** This file may be distributed and/or modified under the terms of the